package exif

var regressExpected = map[string]map[FieldName]string{
	"2004-01-11-22-45-15-sep-2004-01-11-22-45-15a.jpg": map[FieldName]string{
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"2/1"`,
		DateTime:                         `"2004:01:11 22:45:19"`,
		DateTimeDigitized:                `"2004:01:11 22:45:15"`,
		DateTimeOriginal:                 `"2004:01:11 22:45:15"`,
		ExifIFDPointer:                   `251`,
		ExifVersion:                      `"0220"`,
		ExposureBiasValue:                `"95/10"`,
		ExposureProgram:                  `2`,
		ExposureTime:                     `"1000/30000"`,
		FNumber:                          `"320/100"`,
		FileSource:                       `""`,
		Flash:                            `1`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"82/11"`,
		ISOSpeedRatings:                  `150`,
		ImageDescription:                 `"SAMSUNG DIGITAL CAMERA         "`,
		InteroperabilityIFDPointer:       `1009`,
		InteroperabilityIndex:            `"R98"`,
		LightSource:                      `0`,
		Make:                             `"Samsung Techwin"`,
		MaxApertureValue:                 `"32/10"`,
		MeteringMode:                     `2`,
		Model:                            `"U-CA 501"`,
		Orientation:                      `1`,
		PixelXDimension:                  `1600`,
		PixelYDimension:                  `1200`,
		RelatedSoundFile:                 `""`,
		ResolutionUnit:                   `2`,
		SceneType:                        `""`,
		Software:                         `"M5011S-1031"`,
		ThumbJPEGInterchangeFormat:       `1039`,
		ThumbJPEGInterchangeFormatLength: `3530`,
		XResolution:                      `"72/1"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"72/1"`,
	},
	"2006-08-03-16-29-38-sep-2006-08-03-16-29-38a.jpg": map[FieldName]string{
		ApertureValue:                    `"95/32"`,
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"5/1"`,
		CustomRendered:                   `0`,
		DateTime:                         `"2006:08:03 16:29:38"`,
		DateTimeDigitized:                `"2006:08:03 16:29:38"`,
		DateTimeOriginal:                 `"2006:08:03 16:29:38"`,
		DigitalZoomRatio:                 `"2816/2816"`,
		ExifIFDPointer:                   `196`,
		ExifVersion:                      `"0220"`,
		ExposureBiasValue:                `"0/3"`,
		ExposureMode:                     `0`,
		ExposureTime:                     `"1/1500"`,
		FNumber:                          `"28/10"`,
		FileSource:                       `""`,
		Flash:                            `24`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"5800/1000"`,
		FocalPlaneResolutionUnit:         `2`,
		FocalPlaneXResolution:            `"2816000/225"`,
		FocalPlaneYResolution:            `"2112000/169"`,
		InteroperabilityIFDPointer:       `2824`,
		InteroperabilityIndex:            `"R98"`,
		Make:                             `"Canon"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"95/32"`,
		MeteringMode:                     `5`,
		Model:                            `"Canon PowerShot SD600"`,
		Orientation:                      `6`,
		PixelXDimension:                  `2816`,
		PixelYDimension:                  `2112`,
		ResolutionUnit:                   `2`,
		SceneCaptureType:                 `0`,
		SensingMethod:                    `2`,
		ShutterSpeedValue:                `"338/32"`,
		ThumbJPEGInterchangeFormat:       `5108`,
		ThumbJPEGInterchangeFormatLength: `4323`,
		UserComment:                      `""`,
		WhiteBalance:                     `0`,
		XResolution:                      `"180/1"`,
		YCbCrPositioning:                 `1`,
		YResolution:                      `"180/1"`,
	},
	"2006-11-11-19-17-56-sep-2006-11-11-19-17-56a.jpg": map[FieldName]string{
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"4/1"`,
		Contrast:                         `0`,
		CustomRendered:                   `1`,
		DateTime:                         `"2006:11:11 19:17:56"`,
		DateTimeDigitized:                `"2006:11:11 19:17:56"`,
		DateTimeOriginal:                 `"2006:11:11 19:17:56"`,
		DigitalZoomRatio:                 `"0/100"`,
		ExifIFDPointer:                   `284`,
		ExifVersion:                      `"0220"`,
		ExposureBiasValue:                `"0/10"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `2`,
		ExposureTime:                     `"10/601"`,
		FNumber:                          `"28/10"`,
		FileSource:                       `""`,
		Flash:                            `25`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"58/10"`,
		FocalLengthIn35mmFilm:            `38`,
		GainControl:                      `0`,
		ISOSpeedRatings:                  `50`,
		ImageDescription:                 `"          "`,
		InteroperabilityIFDPointer:       `1026`,
		InteroperabilityIndex:            `"R98"`,
		LightSource:                      `0`,
		Make:                             `"NIKON"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"30/10"`,
		MeteringMode:                     `5`,
		Model:                            `"E3200"`,
		Orientation:                      `1`,
		PixelXDimension:                  `2048`,
		PixelYDimension:                  `1536`,
		ResolutionUnit:                   `2`,
		Saturation:                       `0`,
		SceneCaptureType:                 `0`,
		SceneType:                        `""`,
		Sharpness:                        `0`,
		Software:                         `"E3200v1.1"`,
		SubjectDistanceRange:             `0`,
		ThumbJPEGInterchangeFormat:       `4596`,
		ThumbJPEGInterchangeFormatLength: `4546`,
		UserComment:                      `"                                                                                                                     "`,
		WhiteBalance:                     `0`,
		XResolution:                      `"300/1"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"300/1"`,
	},
	"2006-12-10-23-58-20-sep-2006-12-10-23-58-20a.jpg": map[FieldName]string{
		ApertureValue:                    `"95/32"`,
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"3/1"`,
		CustomRendered:                   `0`,
		DateTime:                         `"2006:12:10 23:58:20"`,
		DateTimeDigitized:                `"2006:12:10 23:58:20"`,
		DateTimeOriginal:                 `"2006:12:10 23:58:20"`,
		DigitalZoomRatio:                 `"2272/2272"`,
		ExifIFDPointer:                   `196`,
		ExifVersion:                      `"0220"`,
		ExposureBiasValue:                `"0/3"`,
		ExposureMode:                     `0`,
		ExposureTime:                     `"1/80"`,
		FNumber:                          `"28/10"`,
		FileSource:                       `""`,
		Flash:                            `24`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"250/32"`,
		FocalPlaneResolutionUnit:         `2`,
		FocalPlaneXResolution:            `"2272000/280"`,
		FocalPlaneYResolution:            `"1704000/210"`,
		InteroperabilityIFDPointer:       `1844`,
		InteroperabilityIndex:            `"R98"`,
		Make:                             `"Canon"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"95/32"`,
		MeteringMode:                     `5`,
		Model:                            `"Canon PowerShot A80"`,
		Orientation:                      `1`,
		PixelXDimension:                  `2272`,
		PixelYDimension:                  `1704`,
		ResolutionUnit:                   `2`,
		SceneCaptureType:                 `0`,
		SensingMethod:                    `2`,
		ShutterSpeedValue:                `"202/32"`,
		ThumbJPEGInterchangeFormat:       `2036`,
		ThumbJPEGInterchangeFormatLength: `6465`,
		UserComment:                      `""`,
		WhiteBalance:                     `0`,
		XResolution:                      `"180/1"`,
		YCbCrPositioning:                 `1`,
		YResolution:                      `"180/1"`,
	},
	"2006-12-17-07-09-14-sep-2006-12-17-07-09-14a.jpg": map[FieldName]string{
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"5725504/3145728"`,
		Contrast:                         `0`,
		CustomRendered:                   `0`,
		DateTime:                         `"2006:12:17 07:09:14"`,
		DateTimeDigitized:                `"2006:12:17 07:09:14"`,
		DateTimeOriginal:                 `"2006:12:17 07:09:14"`,
		DigitalZoomRatio:                 `"100/100"`,
		ExifIFDPointer:                   `586`,
		ExifVersion:                      `"0220"`,
		ExposureBiasValue:                `"0/10"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `2`,
		ExposureTime:                     `"1/160"`,
		FNumber:                          `"270/100"`,
		Flash:                            `24`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"62/10"`,
		FocalLengthIn35mmFilm:            `38`,
		ISOSpeedRatings:                  `64`,
		InteroperabilityIFDPointer:       `31048`,
		InteroperabilityIndex:            `"R98"`,
		Make:                             `"PENTAX Corporation"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"27/10"`,
		MeteringMode:                     `5`,
		Model:                            `"PENTAX Optio S6"`,
		Orientation:                      `1`,
		PixelXDimension:                  `2048`,
		PixelYDimension:                  `1536`,
		ResolutionUnit:                   `2`,
		Saturation:                       `0`,
		SceneCaptureType:                 `0`,
		Sharpness:                        `0`,
		Software:                         `"Optio S6 Ver 1.00"`,
		SubjectDistanceRange:             `2`,
		ThumbJPEGInterchangeFormat:       `31172`,
		ThumbJPEGInterchangeFormatLength: `7063`,
		WhiteBalance:                     `0`,
		XResolution:                      `"72/1"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"72/1"`,
	},
	"2006-12-21-15-55-26-sep-2006-12-21-15-55-26a.jpg": map[FieldName]string{
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"8/1"`,
		Contrast:                         `0`,
		CustomRendered:                   `0`,
		DateTime:                         `"2006:12:21 15:55:26"`,
		DateTimeDigitized:                `"2006:12:21 15:55:26"`,
		DateTimeOriginal:                 `"2006:12:21 15:55:26"`,
		ExifIFDPointer:                   `256`,
		ExifVersion:                      `"0220"`,
		ExposureBiasValue:                `"-20/10"`,
		ExposureMode:                     `1`,
		ExposureProgram:                  `2`,
		ExposureTime:                     `"10/400"`,
		FNumber:                          `"28/10"`,
		FileSource:                       `""`,
		Flash:                            `79`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"79/10"`,
		ISOSpeedRatings:                  `100`,
		ImageDescription:                 `"                               "`,
		InteroperabilityIFDPointer:       `2278`,
		InteroperabilityIndex:            `"R98"`,
		LightSource:                      `0`,
		Make:                             `"SONY"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"48/16"`,
		MeteringMode:                     `3`,
		Model:                            `"DSC-W15"`,
		Orientation:                      `1`,
		PixelXDimension:                  `2592`,
		PixelYDimension:                  `1944`,
		ResolutionUnit:                   `2`,
		Saturation:                       `0`,
		SceneCaptureType:                 `0`,
		SceneType:                        `""`,
		Sharpness:                        `0`,
		ThumbJPEGInterchangeFormat:       `2484`,
		ThumbJPEGInterchangeFormatLength: `13571`,
		WhiteBalance:                     `0`,
		XResolution:                      `"72/1"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"72/1"`,
	},
	"2007-01-01-12-00-00-sep-2007-01-01-12-00-00a.jpg": map[FieldName]string{
		ApertureValue:                    `"286/100"`,
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		Contrast:                         `0`,
		CustomRendered:                   `0`,
		DateTimeDigitized:                `"2007:01:01 12:00:00"`,
		DateTimeOriginal:                 `"2007:01:01 12:00:00"`,
		DigitalZoomRatio:                 `"0/10"`,
		ExifIFDPointer:                   `340`,
		ExifVersion:                      `"0221"`,
		ExposureBiasValue:                `"0/10"`,
		ExposureIndex:                    `"200/1"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `2`,
		ExposureTime:                     `"8942/1000000"`,
		FNumber:                          `"270/100"`,
		FileSource:                       `""`,
		Flash:                            `25`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"60/10"`,
		FocalLengthIn35mmFilm:            `36`,
		GainControl:                      `2`,
		ISOSpeedRatings:                  `200`,
		InteroperabilityIFDPointer:       `13816`,
		InteroperabilityIndex:            `"R98"`,
		LightSource:                      `0`,
		Make:                             `"EASTMAN KODAK COMPANY"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"286/100"`,
		MeteringMode:                     `5`,
		Model:                            `"KODAK EASYSHARE C713 ZOOM DIGITAL CAMERA"`,
		Orientation:                      `1`,
		PixelXDimension:                  `1280`,
		PixelYDimension:                  `960`,
		ResolutionUnit:                   `2`,
		Saturation:                       `0`,
		SceneCaptureType:                 `0`,
		SceneType:                        `""`,
		SensingMethod:                    `2`,
		Sharpness:                        `0`,
		ShutterSpeedValue:                `"680/100"`,
		Software:                         `"KODAK EASYSHARE C713 ZOOM DIGITAL CAMERA"`,
		SubjectDistanceRange:             `0`,
		ThumbJPEGInterchangeFormat:       `13848`,
		ThumbJPEGInterchangeFormatLength: `3436`,
		WhiteBalance:                     `0`,
		XResolution:                      `"480/1"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"480/1"`,
	},
	"2007-01-17-21-49-44-sep-2007-01-17-21-49-44a.jpg": map[FieldName]string{
		ApertureValue:                    `"33/10"`,
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CustomRendered:                   `0`,
		DateTime:                         `"2007:01:17 21:49:44"`,
		DateTimeDigitized:                `"2007:01:17 21:49:44"`,
		DateTimeOriginal:                 `"2007:01:17 21:49:44"`,
		ExifIFDPointer:                   `266`,
		ExifVersion:                      `"0220"`,
		ExposureBiasValue:                `"0/10"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `2`,
		ExposureTime:                     `"1/30"`,
		FNumber:                          `"33/10"`,
		FileSource:                       `""`,
		Flash:                            `24`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"73/10"`,
		ISOSpeedRatings:                  `50`,
		ImageDescription:                 `"Digital image  "`,
		InteroperabilityIFDPointer:       `832`,
		InteroperabilityIndex:            `"R98"`,
		LightSource:                      `0`,
		Make:                             `"Digital Camera                 "`,
		MakerNote:                        `"6106789012345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890123456"`,
		MaxApertureValue:                 `"297/100"`,
		MeteringMode:                     `2`,
		Model:                            `"6MP-9Y8        "`,
		Orientation:                      `1`,
		PixelXDimension:                  `2816`,
		PixelYDimension:                  `2112`,
		ResolutionUnit:                   `2`,
		SceneCaptureType:                 `0`,
		SensingMethod:                    `2`,
		ShutterSpeedValue:                `"491/100"`,
		Software:                         `"1.00.018PR         "`,
		ThumbJPEGInterchangeFormat:       `956`,
		ThumbJPEGInterchangeFormatLength: `7024`,
		WhiteBalance:                     `0`,
		XResolution:                      `"180/1"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"180/1"`,
	},
	"2007-02-02-18-13-29-sep-2007-02-02-18-13-29a.jpg": map[FieldName]string{
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"27033600/4915200"`,
		Contrast:                         `0`,
		CustomRendered:                   `0`,
		DateTime:                         `"2007:02:02 18:13:29"`,
		DateTimeDigitized:                `"2007:02:02 18:13:29"`,
		DateTimeOriginal:                 `"2007:02:02 18:13:29"`,
		DigitalZoomRatio:                 `"0/0"`,
		ExifIFDPointer:                   `586`,
		ExifVersion:                      `"0220"`,
		ExposureBiasValue:                `"0/3"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `2`,
		ExposureTime:                     `"1/60"`,
		FNumber:                          `"26/10"`,
		Flash:                            `25`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"580/100"`,
		FocalLengthIn35mmFilm:            `35`,
		ISOSpeedRatings:                  `200`,
		InteroperabilityIFDPointer:       `30974`,
		InteroperabilityIndex:            `"R98"`,
		Make:                             `"PENTAX Corporation "`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"28/10"`,
		MeteringMode:                     `5`,
		Model:                            `"PENTAX Optio S5z "`,
		Orientation:                      `1`,
		PixelXDimension:                  `2560`,
		PixelYDimension:                  `1920`,
		ResolutionUnit:                   `2`,
		Saturation:                       `0`,
		SceneCaptureType:                 `0`,
		Sharpness:                        `0`,
		Software:                         `"Optio S5z Ver 1.00 "`,
		SubjectDistanceRange:             `2`,
		ThumbJPEGInterchangeFormat:       `31098`,
		ThumbJPEGInterchangeFormatLength: `8800`,
		WhiteBalance:                     `0`,
		XResolution:                      `"72/1"`,
		YCbCrPositioning:                 `1`,
		YResolution:                      `"72/1"`,
	},
	"2007-05-02-17-02-21-sep-2007-05-02-17-02-21a.jpg": map[FieldName]string{
		ApertureValue:                    `"107/32"`,
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"3/1"`,
		CustomRendered:                   `0`,
		DateTime:                         `"2007:05:02 17:02:21"`,
		DateTimeDigitized:                `"2007:05:02 17:02:21"`,
		DateTimeOriginal:                 `"2007:05:02 17:02:21"`,
		DigitalZoomRatio:                 `"2592/2592"`,
		ExifIFDPointer:                   `196`,
		ExifVersion:                      `"0220"`,
		ExposureBiasValue:                `"0/3"`,
		ExposureMode:                     `0`,
		ExposureTime:                     `"1/60"`,
		FNumber:                          `"32/10"`,
		FileSource:                       `""`,
		Flash:                            `9`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"7109/1000"`,
		FocalPlaneResolutionUnit:         `2`,
		FocalPlaneXResolution:            `"1600000/225"`,
		FocalPlaneYResolution:            `"1200000/168"`,
		InteroperabilityIFDPointer:       `2226`,
		InteroperabilityIndex:            `"R98"`,
		Make:                             `"Canon"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"107/32"`,
		MeteringMode:                     `5`,
		Model:                            `"Canon IXY DIGITAL 55"`,
		Orientation:                      `1`,
		PixelXDimension:                  `1600`,
		PixelYDimension:                  `1200`,
		ResolutionUnit:                   `2`,
		SceneCaptureType:                 `0`,
		SensingMethod:                    `2`,
		ShutterSpeedValue:                `"189/32"`,
		ThumbJPEGInterchangeFormat:       `5108`,
		ThumbJPEGInterchangeFormatLength: `6306`,
		UserComment:                      `""`,
		WhiteBalance:                     `0`,
		XResolution:                      `"180/1"`,
		YCbCrPositioning:                 `1`,
		YResolution:                      `"180/1"`,
	},
	"2007-05-12-08-19-07-sep-2007-05-12-08-19-07a.jpg": map[FieldName]string{
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"252746/307200"`,
		Contrast:                         `0`,
		CustomRendered:                   `0`,
		DateTime:                         `"2007:06:17 22:56:38"`,
		DateTimeDigitized:                `"2007:06:17 22:56:38"`,
		DateTimeOriginal:                 `"2007:05:12 08:19:07"`,
		DigitalZoomRatio:                 `"0/0"`,
		ExifIFDPointer:                   `282`,
		ExifVersion:                      `"0221"`,
		ExposureBiasValue:                `"0/3"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `2`,
		ExposureTime:                     `"1/50"`,
		FNumber:                          `"31/10"`,
		FileSource:                       `""`,
		Flash:                            `16`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"630/100"`,
		FocalLengthIn35mmFilm:            `38`,
		GainControl:                      `2`,
		InteroperabilityIFDPointer:       `27298`,
		InteroperabilityIndex:            `"R98"`,
		LightSource:                      `0`,
		Make:                             `"CASIO COMPUTER CO.,LTD."`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"33/10"`,
		MeteringMode:                     `5`,
		Model:                            `"EX-Z70     "`,
		Orientation:                      `1`,
		PixelXDimension:                  `640`,
		PixelYDimension:                  `480`,
		ResolutionUnit:                   `2`,
		Saturation:                       `0`,
		SceneCaptureType:                 `0`,
		Sharpness:                        `0`,
		Software:                         `"1.00             "`,
		ThumbJPEGInterchangeFormat:       `27422`,
		ThumbJPEGInterchangeFormatLength: `8332`,
		WhiteBalance:                     `0`,
		XResolution:                      `"72/1"`,
		YCbCrPositioning:                 `1`,
		YResolution:                      `"72/1"`,
	},
	"2007-05-26-04-49-45-sep-2007-05-26-04-49-45a.jpg": map[FieldName]string{
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"4/1"`,
		Contrast:                         `0`,
		CustomRendered:                   `0`,
		DateTime:                         `"2007:05:26 04:49:45"`,
		DateTimeDigitized:                `"2007:05:26 04:49:45"`,
		DateTimeOriginal:                 `"2007:05:26 04:49:45"`,
		DigitalZoomRatio:                 `"0/100"`,
		ExifIFDPointer:                   `284`,
		ExifVersion:                      `"0220"`,
		ExposureBiasValue:                `"0/10"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `2`,
		ExposureTime:                     `"10/3486"`,
		FNumber:                          `"32/10"`,
		FileSource:                       `""`,
		Flash:                            `24`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"63/10"`,
		FocalLengthIn35mmFilm:            `38`,
		GainControl:                      `0`,
		ISOSpeedRatings:                  `50`,
		ImageDescription:                 `"          "`,
		InteroperabilityIFDPointer:       `1026`,
		InteroperabilityIndex:            `"R98"`,
		LightSource:                      `0`,
		Make:                             `"NIKON"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"34/10"`,
		MeteringMode:                     `5`,
		Model:                            `"COOLPIX L3"`,
		Orientation:                      `1`,
		PixelXDimension:                  `2592`,
		PixelYDimension:                  `1944`,
		ResolutionUnit:                   `2`,
		Saturation:                       `0`,
		SceneCaptureType:                 `2`,
		SceneType:                        `""`,
		Sharpness:                        `0`,
		Software:                         `"COOLPIX L3v1.2"`,
		SubjectDistanceRange:             `0`,
		ThumbJPEGInterchangeFormat:       `4596`,
		ThumbJPEGInterchangeFormatLength: `10120`,
		UserComment:                      `"                                                                                                                     "`,
		WhiteBalance:                     `0`,
		XResolution:                      `"300/1"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"300/1"`,
	},
	"2007-05-30-14-28-01-sep-2007-05-30-14-28-01a.jpg": map[FieldName]string{
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"2/1"`,
		Contrast:                         `0`,
		CustomRendered:                   `0`,
		DateTime:                         `"2007:05:30 14:28:01"`,
		DateTimeDigitized:                `"2007:05:30 14:28:01"`,
		DateTimeOriginal:                 `"2007:05:30 14:28:01"`,
		DigitalZoomRatio:                 `"0/100"`,
		ExifIFDPointer:                   `284`,
		ExifVersion:                      `"0220"`,
		ExposureBiasValue:                `"0/10"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `2`,
		ExposureTime:                     `"10/40"`,
		FNumber:                          `"30/10"`,
		FileSource:                       `""`,
		Flash:                            `16`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"58/10"`,
		FocalLengthIn35mmFilm:            `35`,
		GainControl:                      `1`,
		ISOSpeedRatings:                  `53`,
		ImageDescription:                 `"          "`,
		InteroperabilityIFDPointer:       `1026`,
		InteroperabilityIndex:            `"R98"`,
		LightSource:                      `0`,
		Make:                             `"NIKON"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"32/10"`,
		MeteringMode:                     `5`,
		Model:                            `"COOLPIX S6"`,
		Orientation:                      `1`,
		PixelXDimension:                  `2816`,
		PixelYDimension:                  `2112`,
		ResolutionUnit:                   `2`,
		Saturation:                       `0`,
		SceneCaptureType:                 `0`,
		SceneType:                        `""`,
		Sharpness:                        `0`,
		Software:                         `"COOLPIX S6V1.0"`,
		SubjectDistanceRange:             `0`,
		ThumbJPEGInterchangeFormat:       `4596`,
		ThumbJPEGInterchangeFormatLength: `5274`,
		UserComment:                      `"                                                                                                                     "`,
		WhiteBalance:                     `0`,
		XResolution:                      `"300/1"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"300/1"`,
	},
	"2007-06-06-16-15-25-sep-2007-06-06-16-15-25a.jpg": map[FieldName]string{
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"2/1"`,
		Contrast:                         `0`,
		CustomRendered:                   `0`,
		DateTime:                         `"2007:06:06 16:15:25"`,
		DateTimeDigitized:                `"2007:06:06 16:15:25"`,
		DateTimeOriginal:                 `"2007:06:06 16:15:25"`,
		DigitalZoomRatio:                 `"0/100"`,
		ExifIFDPointer:                   `284`,
		ExifVersion:                      `"0220"`,
		ExposureBiasValue:                `"0/10"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `2`,
		ExposureTime:                     `"10/2870"`,
		FNumber:                          `"48/10"`,
		FileSource:                       `""`,
		Flash:                            `24`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"54/10"`,
		FocalLengthIn35mmFilm:            `35`,
		GainControl:                      `0`,
		ISOSpeedRatings:                  `50`,
		ImageDescription:                 `"          "`,
		InteroperabilityIFDPointer:       `1026`,
		InteroperabilityIndex:            `"R98"`,
		LightSource:                      `0`,
		Make:                             `"NIKON"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"30/10"`,
		MeteringMode:                     `5`,
		Model:                            `"E3700"`,
		Orientation:                      `1`,
		PixelXDimension:                  `2048`,
		PixelYDimension:                  `1536`,
		ResolutionUnit:                   `2`,
		Saturation:                       `0`,
		SceneCaptureType:                 `0`,
		SceneType:                        `""`,
		Sharpness:                        `0`,
		Software:                         `"E3700v1.2"`,
		SubjectDistanceRange:             `0`,
		ThumbJPEGInterchangeFormat:       `4596`,
		ThumbJPEGInterchangeFormatLength: `5967`,
		UserComment:                      `"                                                                                                                     "`,
		WhiteBalance:                     `0`,
		XResolution:                      `"300/1"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"300/1"`,
	},
	"2007-06-26-10-13-04-sep-2007-06-26-10-13-04a.jpg": map[FieldName]string{
		ApertureValue:                    `"3/1"`,
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"6389872/3145728"`,
		Copyright:                        `"Copyright2004"`,
		DateTime:                         `"2007:06:26 10:13:04"`,
		DateTimeDigitized:                `"2007:06:26 10:13:04"`,
		DateTimeOriginal:                 `"2007:06:26 10:13:04"`,
		ExifIFDPointer:                   `262`,
		ExifVersion:                      `"0210"`,
		ExposureBiasValue:                `"1/4"`,
		ExposureIndex:                    `"146/1"`,
		ExposureProgram:                  `3`,
		ExposureTime:                     `"23697424/268435456"`,
		FNumber:                          `"3/1"`,
		FileSource:                       `""`,
		Flash:                            `0`,
		FlashpixVersion:                  `"0100"`,
		ISOSpeedRatings:                  `100`,
		ImageDescription:                 `"My beautiful picture"`,
		InteroperabilityIFDPointer:       `1170`,
		InteroperabilityIndex:            `"R98"`,
		LightSource:                      `0`,
		Make:                             `"CEC"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"3/1"`,
		MeteringMode:                     `2`,
		Model:                            `"DV"`,
		Orientation:                      `1`,
		PixelXDimension:                  `2048`,
		PixelYDimension:                  `1536`,
		RelatedSoundFile:                 `"RelatedSound"`,
		ResolutionUnit:                   `2`,
		SceneType:                        `""`,
		SensingMethod:                    `2`,
		ShutterSpeedValue:                `"7/1"`,
		Software:                         `"DVWare 1.0"`,
		ThumbJPEGInterchangeFormat:       `1306`,
		ThumbJPEGInterchangeFormatLength: `6292`,
		XResolution:                      `"320/1"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"384/1"`,
	},
	"2007-07-13-17-02-30-sep-2007-07-13-17-02-30a.jpg": map[FieldName]string{
		ApertureValue:                    `"45/10"`,
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		Contrast:                         `0`,
		CustomRendered:                   `0`,
		DateTime:                         `"2007:07:13 17:02:30"`,
		DateTimeDigitized:                `"2007:07:13 17:02:30"`,
		DateTimeOriginal:                 `"2007:07:13 17:02:30"`,
		DigitalZoomRatio:                 `"100/100"`,
		ExifIFDPointer:                   `266`,
		ExifVersion:                      `"0220"`,
		ExposureBiasValue:                `"0/10"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `2`,
		ExposureTime:                     `"1/110"`,
		FNumber:                          `"48/10"`,
		FileSource:                       `""`,
		Flash:                            `0`,
		FlashpixVersion:                  `"0100"`,
		FocalLengthIn35mmFilm:            `35`,
		GainControl:                      `0`,
		ISOSpeedRatings:                  `64`,
		ImageDescription:                 `"Digital StillCamera"`,
		InteroperabilityIFDPointer:       `1010`,
		InteroperabilityIndex:            `"R98"`,
		LightSource:                      `0`,
		Make:                             `"Vivitar"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"30/10"`,
		MeteringMode:                     `2`,
		Model:                            `"ViviCam X30 "`,
		Orientation:                      `1`,
		PixelXDimension:                  `3648`,
		PixelYDimension:                  `2736`,
		RelatedSoundFile:                 `"            "`,
		ResolutionUnit:                   `2`,
		Saturation:                       `0`,
		SceneCaptureType:                 `0`,
		Sharpness:                        `0`,
		ShutterSpeedValue:                `"678/100"`,
		Software:                         `"Ver 1.00    "`,
		SubjectDistanceRange:             `0`,
		ThumbJPEGInterchangeFormat:       `1156`,
		ThumbJPEGInterchangeFormatLength: `20544`,
		WhiteBalance:                     `0`,
		XResolution:                      `"72/1"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"72/1"`,
	},
	"2007-08-15-14-42-46-sep-2007-08-15-14-42-46a.jpg": map[FieldName]string{
		ApertureValue:                    `"37/10"`,
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		Contrast:                         `0`,
		CustomRendered:                   `0`,
		DateTimeDigitized:                `"2007:08:15 14:42:46"`,
		DateTimeOriginal:                 `"2007:08:15 14:42:46"`,
		DigitalZoomRatio:                 `"0/100"`,
		ExifIFDPointer:                   `320`,
		ExifVersion:                      `"0221"`,
		ExposureBiasValue:                `"0/3"`,
		ExposureIndex:                    `"80/1"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `2`,
		ExposureTime:                     `"1/160"`,
		FNumber:                          `"36/10"`,
		FileSource:                       `""`,
		Flash:                            `24`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"110/10"`,
		FocalLengthIn35mmFilm:            `66`,
		GainControl:                      `0`,
		ISOSpeedRatings:                  `80`,
		LightSource:                      `0`,
		Make:                             `"EASTMAN KODAK COMPANY"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"37/10"`,
		MeteringMode:                     `5`,
		Model:                            `"KODAK C663 ZOOM DIGITAL CAMERA"`,
		Orientation:                      `1`,
		PixelXDimension:                  `2832`,
		PixelYDimension:                  `2128`,
		ResolutionUnit:                   `2`,
		Saturation:                       `0`,
		SceneCaptureType:                 `0`,
		SceneType:                        `""`,
		SensingMethod:                    `2`,
		Sharpness:                        `0`,
		ShutterSpeedValue:                `"73/10"`,
		SubjectDistanceRange:             `0`,
		ThumbJPEGInterchangeFormat:       `8472`,
		ThumbJPEGInterchangeFormatLength: `3060`,
		WhiteBalance:                     `0`,
		XResolution:                      `"230/1"`,
		YCbCrPositioning:                 `1`,
		YResolution:                      `"230/1"`,
	},
	"2007-08-24-02-40-42-sep-2007-08-24-02-40-42a.jpg": map[FieldName]string{
		ApertureValue:                    `"213/32"`,
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"5/1"`,
		CustomRendered:                   `0`,
		DateTime:                         `"2007:08:24 02:40:42"`,
		DateTimeDigitized:                `"2007:08:24 02:40:42"`,
		DateTimeOriginal:                 `"2007:08:24 02:40:42"`,
		DigitalZoomRatio:                 `"2592/2592"`,
		ExifIFDPointer:                   `196`,
		ExifVersion:                      `"0220"`,
		ExposureBiasValue:                `"0/3"`,
		ExposureMode:                     `0`,
		ExposureTime:                     `"1/400"`,
		FNumber:                          `"100/10"`,
		FileSource:                       `""`,
		Flash:                            `24`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"17400/1000"`,
		FocalPlaneResolutionUnit:         `2`,
		FocalPlaneXResolution:            `"2592000/225"`,
		FocalPlaneYResolution:            `"1944000/168"`,
		InteroperabilityIFDPointer:       `2206`,
		InteroperabilityIndex:            `"R98"`,
		Make:                             `"Canon"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"147/32"`,
		MeteringMode:                     `5`,
		Model:                            `"Canon PowerShot SD450"`,
		Orientation:                      `1`,
		PixelXDimension:                  `2592`,
		PixelYDimension:                  `1944`,
		ResolutionUnit:                   `2`,
		SceneCaptureType:                 `0`,
		SensingMethod:                    `2`,
		ShutterSpeedValue:                `"277/32"`,
		ThumbJPEGInterchangeFormat:       `5108`,
		ThumbJPEGInterchangeFormatLength: `2084`,
		UserComment:                      `""`,
		WhiteBalance:                     `0`,
		XResolution:                      `"180/1"`,
		YCbCrPositioning:                 `1`,
		YResolution:                      `"180/1"`,
	},
	"2007-11-07-11-40-44-sep-2007-11-07-11-40-44a.jpg": map[FieldName]string{
		ApertureValue:                    `"600/100"`,
		BrightnessValue:                  `"906/100"`,
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"20/10"`,
		Copyright:                        `"    "`,
		CustomRendered:                   `1`,
		DateTime:                         `"2007:11:07 11:40:44"`,
		DateTimeDigitized:                `"2007:11:07 11:40:44"`,
		DateTimeOriginal:                 `"2007:11:07 11:40:44"`,
		ExifIFDPointer:                   `294`,
		ExifVersion:                      `"0220"`,
		ExposureBiasValue:                `"0/100"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `2`,
		ExposureTime:                     `"10/2000"`,
		FNumber:                          `"800/100"`,
		FileSource:                       `""`,
		Flash:                            `16`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"610/100"`,
		FocalPlaneResolutionUnit:         `3`,
		FocalPlaneXResolution:            `"4442/1"`,
		FocalPlaneYResolution:            `"4442/1"`,
		ISOSpeedRatings:                  `64`,
		InteroperabilityIFDPointer:       `1158`,
		InteroperabilityIndex:            `"R98"`,
		LightSource:                      `0`,
		Make:                             `"FUJIFILM"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"360/100"`,
		MeteringMode:                     `5`,
		Model:                            `"FinePix Z1     "`,
		Orientation:                      `1`,
		PixelXDimension:                  `2592`,
		PixelYDimension:                  `1944`,
		ResolutionUnit:                   `2`,
		SceneCaptureType:                 `0`,
		SceneType:                        `""`,
		SensingMethod:                    `2`,
		Sharpness:                        `0`,
		ShutterSpeedValue:                `"764/100"`,
		Software:                         `"Digital Camera FinePix Z1      Ver1.00"`,
		SubjectDistanceRange:             `0`,
		ThumbJPEGInterchangeFormat:       `1306`,
		ThumbJPEGInterchangeFormatLength: `9900`,
		WhiteBalance:                     `0`,
		XResolution:                      `"72/1"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"72/1"`,
	},
	"2008-06-02-10-03-57-sep-2008-06-02-10-03-57a.jpg": map[FieldName]string{
		ApertureValue:                    `"2970/1000"`,
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"5896224/3145728"`,
		Copyright:                        `"Copyright 2006"`,
		DateTime:                         `"2008:06:13 06:16:19"`,
		DateTimeDigitized:                `"2008:06:13 06:16:19"`,
		DateTimeOriginal:                 `"2008:06:02 10:03:57"`,
		DigitalZoomRatio:                 `"100/100"`,
		ExifIFDPointer:                   `226`,
		ExifVersion:                      `"0220"`,
		ExposureBiasValue:                `"0/10"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `7`,
		ExposureTime:                     `"10/600"`,
		FNumber:                          `"2800/1000"`,
		FileSource:                       `""`,
		Flash:                            `65`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"6200/1000"`,
		ISOSpeedRatings:                  `100`,
		InteroperabilityIFDPointer:       `3620`,
		InteroperabilityIndex:            `"R98"`,
		LightSource:                      `4`,
		Make:                             `"Polaroid"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"2970/1000"`,
		MeteringMode:                     `4`,
		Model:                            `"i533"`,
		Orientation:                      `1`,
		PixelXDimension:                  `2048`,
		PixelYDimension:                  `1536`,
		ResolutionUnit:                   `2`,
		SceneType:                        `""`,
		SensingMethod:                    `2`,
		Sharpness:                        `0`,
		ShutterSpeedValue:                `"5907/1000"`,
		Software:                         `"00.00.1240a"`,
		ThumbJPEGInterchangeFormat:       `3756`,
		ThumbJPEGInterchangeFormatLength: `5972`,
		WhiteBalance:                     `0`,
		XResolution:                      `"288/3"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"288/3"`,
	},
	"2008-06-06-13-29-29-sep-2008-06-06-13-29-29a.jpg": map[FieldName]string{
		ApertureValue:                    `"116/32"`,
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"5/1"`,
		CustomRendered:                   `0`,
		DateTime:                         `"2008:06:06 13:29:29"`,
		DateTimeDigitized:                `"2008:06:06 13:29:29"`,
		DateTimeOriginal:                 `"2008:06:06 13:29:29"`,
		DigitalZoomRatio:                 `"3072/3072"`,
		ExifIFDPointer:                   `196`,
		ExifVersion:                      `"0220"`,
		ExposureBiasValue:                `"0/3"`,
		ExposureMode:                     `0`,
		ExposureTime:                     `"1/320"`,
		FNumber:                          `"35/10"`,
		FileSource:                       `""`,
		Flash:                            `16`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"8462/1000"`,
		FocalPlaneResolutionUnit:         `2`,
		FocalPlaneXResolution:            `"1600000/225"`,
		FocalPlaneYResolution:            `"1200000/169"`,
		ISOSpeedRatings:                  `80`,
		InteroperabilityIFDPointer:       `3334`,
		InteroperabilityIndex:            `"R98"`,
		Make:                             `"Canon"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"116/32"`,
		MeteringMode:                     `5`,
		Model:                            `"Canon DIGITAL IXUS 75"`,
		Orientation:                      `6`,
		PixelXDimension:                  `1600`,
		PixelYDimension:                  `1200`,
		ResolutionUnit:                   `2`,
		SceneCaptureType:                 `0`,
		SensingMethod:                    `2`,
		ShutterSpeedValue:                `"266/32"`,
		ThumbJPEGInterchangeFormat:       `5108`,
		ThumbJPEGInterchangeFormatLength: `6594`,
		UserComment:                      `""`,
		WhiteBalance:                     `0`,
		XResolution:                      `"180/1"`,
		YCbCrPositioning:                 `1`,
		YResolution:                      `"180/1"`,
	},
	"2008-06-17-01-21-30-sep-2008-06-17-01-21-30a.jpg": map[FieldName]string{
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"2/1"`,
		DateTime:                         `"2008:06:17 01:22:13"`,
		DateTimeDigitized:                `"2008:06:17 01:21:30"`,
		DateTimeOriginal:                 `"2008:06:17 01:21:30"`,
		ExifIFDPointer:                   `253`,
		ExifVersion:                      `"0220"`,
		ExposureBiasValue:                `"0/10"`,
		ExposureProgram:                  `2`,
		ExposureTime:                     `"10/326"`,
		FNumber:                          `"28/10"`,
		FileSource:                       `""`,
		Flash:                            `0`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"645/100"`,
		ISOSpeedRatings:                  `100`,
		ImageDescription:                 `"DCFC1247.JPG                   "`,
		InteroperabilityIFDPointer:       `1011`,
		InteroperabilityIndex:            `"R98"`,
		LightSource:                      `0`,
		Make:                             `"Polaroid"`,
		MaxApertureValue:                 `"30/10"`,
		MeteringMode:                     `2`,
		Model:                            `"5MP Digital Camera"`,
		Orientation:                      `1`,
		PixelXDimension:                  `2592`,
		PixelYDimension:                  `1944`,
		ResolutionUnit:                   `2`,
		SceneType:                        `""`,
		Software:                         `"A520_CT019"`,
		ThumbJPEGInterchangeFormat:       `1041`,
		ThumbJPEGInterchangeFormatLength: `13506`,
		UserComment:                      `""`,
		XResolution:                      `"72/1"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"72/1"`,
	},
	"2008-09-02-17-43-48-sep-2008-09-02-17-43-48a.jpg": map[FieldName]string{
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		DateTime:                         `"2008:09:02 17:43:48"`,
		DateTimeDigitized:                `"2008:09:02 17:43:48"`,
		DateTimeOriginal:                 `"2008:09:02 17:43:48"`,
		ExifIFDPointer:                   `302`,
		ExifVersion:                      `"0220"`,
		FlashpixVersion:                  `"0100"`,
		ImageDescription:                 `"                               "`,
		InteroperabilityIFDPointer:       `612`,
		InteroperabilityIndex:            `"R98"`,
		Make:                             `"Sony Ericsson"`,
		Model:                            `"Z550a"`,
		Orientation:                      `1`,
		PixelXDimension:                  `1280`,
		PixelYDimension:                  `1024`,
		ResolutionUnit:                   `2`,
		Software:                         `"R6GA004     prgCXC1250583_GENERIC_M 2.0"`,
		ThumbJPEGInterchangeFormat:       `748`,
		ThumbJPEGInterchangeFormatLength: `4641`,
		XResolution:                      `"72/1"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"72/1"`,
	},
	"2009-03-26-09-23-20-sep-2009-03-26-09-23-20a.jpg": map[FieldName]string{
		ApertureValue:                    `"95/32"`,
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"5/1"`,
		CustomRendered:                   `0`,
		DateTime:                         `"2009:03:26 09:23:20"`,
		DateTimeDigitized:                `"2009:03:26 09:23:20"`,
		DateTimeOriginal:                 `"2009:03:26 09:23:20"`,
		DigitalZoomRatio:                 `"3072/3072"`,
		ExifIFDPointer:                   `196`,
		ExifVersion:                      `"0220"`,
		ExposureBiasValue:                `"0/3"`,
		ExposureMode:                     `0`,
		ExposureTime:                     `"1/500"`,
		FNumber:                          `"28/10"`,
		FileSource:                       `""`,
		Flash:                            `24`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"5800/1000"`,
		FocalPlaneResolutionUnit:         `2`,
		FocalPlaneXResolution:            `"3072000/225"`,
		FocalPlaneYResolution:            `"2304000/169"`,
		ISOSpeedRatings:                  `160`,
		InteroperabilityIFDPointer:       `3334`,
		InteroperabilityIndex:            `"R98"`,
		Make:                             `"Canon"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"95/32"`,
		MeteringMode:                     `5`,
		Model:                            `"Canon PowerShot SD750"`,
		Orientation:                      `1`,
		PixelXDimension:                  `3072`,
		PixelYDimension:                  `2304`,
		ResolutionUnit:                   `2`,
		SceneCaptureType:                 `0`,
		SensingMethod:                    `2`,
		ShutterSpeedValue:                `"287/32"`,
		ThumbJPEGInterchangeFormat:       `5108`,
		ThumbJPEGInterchangeFormatLength: `5513`,
		UserComment:                      `""`,
		WhiteBalance:                     `0`,
		XResolution:                      `"180/1"`,
		YCbCrPositioning:                 `1`,
		YResolution:                      `"180/1"`,
	},
	"2009-04-11-03-01-38-sep-2009-04-11-03-01-38a.jpg": map[FieldName]string{
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"4/1"`,
		Contrast:                         `0`,
		CustomRendered:                   `0`,
		DateTime:                         `"2009:04:11 03:01:38"`,
		DateTimeDigitized:                `"2009:04:11 03:01:38"`,
		DateTimeOriginal:                 `"2009:04:11 03:01:38"`,
		DigitalZoomRatio:                 `"0/100"`,
		ExifIFDPointer:                   `230`,
		ExifVersion:                      `"0220"`,
		ExposureBiasValue:                `"0/10"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `2`,
		ExposureTime:                     `"1/250"`,
		FNumber:                          `"28/10"`,
		FileSource:                       `""`,
		Flash:                            `24`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"5700/1000"`,
		FocalLengthIn35mmFilm:            `35`,
		GainControl:                      `1`,
		ISOSpeedRatings:                  `227`,
		ImageDescription:                 `"          "`,
		InteroperabilityIFDPointer:       `33536`,
		InteroperabilityIndex:            `"R98"`,
		LightSource:                      `0`,
		Make:                             `"NIKON"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"30/10"`,
		MeteringMode:                     `5`,
		Model:                            `"COOLPIX L18"`,
		Orientation:                      `1`,
		PixelXDimension:                  `3264`,
		PixelYDimension:                  `2448`,
		ResolutionUnit:                   `2`,
		Saturation:                       `0`,
		SceneCaptureType:                 `0`,
		SceneType:                        `""`,
		Sharpness:                        `1`,
		Software:                         `"COOLPIX L18 V1.1"`,
		SubjectDistanceRange:             `0`,
		ThumbJPEGInterchangeFormat:       `33660`,
		ThumbJPEGInterchangeFormatLength: `9697`,
		UserComment:                      `"       "`,
		WhiteBalance:                     `0`,
		XResolution:                      `"300/1"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"300/1"`,
	},
	"2009-04-23-07-21-35-sep-2009-04-23-07-21-35a.jpg": map[FieldName]string{
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"13301888/4915200"`,
		Contrast:                         `0`,
		CustomRendered:                   `0`,
		DateTime:                         `"2009:04:23 07:21:35"`,
		DateTimeDigitized:                `"2009:04:23 07:21:35"`,
		DateTimeOriginal:                 `"2009:04:23 07:21:35"`,
		DigitalZoomRatio:                 `"0/100"`,
		ExifIFDPointer:                   `590`,
		ExifVersion:                      `"0220"`,
		ExposureBiasValue:                `"0/10"`,
		ExposureMode:                     `0`,
		ExposureTime:                     `"1/40"`,
		FNumber:                          `"26/10"`,
		Flash:                            `9`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"58/10"`,
		FocalLengthIn35mmFilm:            `35`,
		ISOSpeedRatings:                  `100`,
		InteroperabilityIFDPointer:       `31040`,
		InteroperabilityIndex:            `"R98"`,
		Make:                             `"PENTAX Corporation"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"28/10"`,
		MeteringMode:                     `5`,
		Model:                            `"PENTAX Optio S50"`,
		Orientation:                      `1`,
		PixelXDimension:                  `2560`,
		PixelYDimension:                  `1920`,
		ResolutionUnit:                   `2`,
		Saturation:                       `0`,
		SceneCaptureType:                 `0`,
		Sharpness:                        `0`,
		Software:                         `"Optio S50 Ver 1.00"`,
		SubjectDistanceRange:             `3`,
		ThumbJPEGInterchangeFormat:       `31176`,
		ThumbJPEGInterchangeFormatLength: `6015`,
		WhiteBalance:                     `0`,
		XResolution:                      `"72/1"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"72/1"`,
	},
	"2009-06-11-19-23-18-sep-2009-06-11-19-23-18a.jpg": map[FieldName]string{
		ApertureValue:                    `"11257/1627"`,
		ColorSpace:                       `65535`,
		DateTime:                         `"2009:06:23 18:42:05"`,
		DateTimeDigitized:                `"2009:06:11 19:23:18"`,
		DateTimeOriginal:                 `"2009:06:11 19:23:18"`,
		ExifIFDPointer:                   `264`,
		ExifVersion:                      `"0220"`,
		ExposureBiasValue:                `"0/1"`,
		ExposureProgram:                  `1`,
		ExposureTime:                     `"1/4"`,
		Flash:                            `16`,
		FocalLength:                      `"47/1"`,
		ISOSpeedRatings:                  `200`,
		Make:                             `"Canon"`,
		MeteringMode:                     `1`,
		Model:                            `"Canon EOS DIGITAL REBEL XTi"`,
		Orientation:                      `1`,
		PixelXDimension:                  `1400`,
		PixelYDimension:                  `2100`,
		ResolutionUnit:                   `2`,
		Software:                         `"Adobe Photoshop CS3 Macintosh"`,
		ThumbJPEGInterchangeFormat:       `606`,
		ThumbJPEGInterchangeFormatLength: `7150`,
		XResolution:                      `"3500000/10000"`,
		YCbCrPositioning:                 `1`,
		YResolution:                      `"3500000/10000"`,
	},
	"2009-06-20-07-59-05-sep-2009-06-20-07-59-05a.jpg": map[FieldName]string{
		ApertureValue:                    `"36/10"`,
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		Contrast:                         `0`,
		CustomRendered:                   `0`,
		DateTimeDigitized:                `"2009:06:20 07:59:05"`,
		DateTimeOriginal:                 `"2009:06:20 07:59:05"`,
		DigitalZoomRatio:                 `"0/100"`,
		ExifIFDPointer:                   `514`,
		ExifVersion:                      `"0221"`,
		ExposureBiasValue:                `"0/3"`,
		ExposureIndex:                    `"160/1"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `2`,
		ExposureTime:                     `"1/500"`,
		FNumber:                          `"35/10"`,
		FileSource:                       `""`,
		Flash:                            `89`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"559/10"`,
		FocalLengthIn35mmFilm:            `337`,
		GainControl:                      `2`,
		ISOSpeedRatings:                  `160`,
		InteroperabilityIFDPointer:       `8728`,
		InteroperabilityIndex:            `"R98"`,
		LightSource:                      `0`,
		Make:                             `"EASTMAN KODAK COMPANY"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"36/10"`,
		MeteringMode:                     `5`,
		Model:                            `"KODAK EASYSHARE Z710 ZOOM DIGITAL CAMERA"`,
		Orientation:                      `1`,
		PixelXDimension:                  `3072`,
		PixelYDimension:                  `2304`,
		ResolutionUnit:                   `2`,
		Saturation:                       `0`,
		SceneCaptureType:                 `0`,
		SceneType:                        `""`,
		SensingMethod:                    `2`,
		Sharpness:                        `0`,
		ShutterSpeedValue:                `"9/1"`,
		SubjectDistanceRange:             `0`,
		ThumbJPEGInterchangeFormat:       `9032`,
		ThumbJPEGInterchangeFormatLength: `4569`,
		WhiteBalance:                     `0`,
		XResolution:                      `"480/1"`,
		YCbCrPositioning:                 `1`,
		YResolution:                      `"480/1"`,
	},
	"2009-08-05-08-11-31-sep-2009-08-05-08-11-31a.jpg": map[FieldName]string{
		ApertureValue:                    `"400/100"`,
		BrightnessValue:                  `"719/100"`,
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"20/10"`,
		Copyright:                        `"    "`,
		CustomRendered:                   `0`,
		DateTime:                         `"2009:08:05 08:11:31"`,
		DateTimeDigitized:                `"2009:08:05 08:11:31"`,
		DateTimeOriginal:                 `"2009:08:05 08:11:31"`,
		ExifIFDPointer:                   `294`,
		ExifVersion:                      `"0220"`,
		ExposureBiasValue:                `"0/100"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `2`,
		ExposureTime:                     `"10/3000"`,
		FNumber:                          `"400/100"`,
		FileSource:                       `""`,
		Flash:                            `16`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"720/100"`,
		FocalPlaneResolutionUnit:         `3`,
		FocalPlaneXResolution:            `"5292/1"`,
		FocalPlaneYResolution:            `"5292/1"`,
		ISOSpeedRatings:                  `100`,
		InteroperabilityIFDPointer:       `1158`,
		InteroperabilityIndex:            `"R98"`,
		LightSource:                      `0`,
		Make:                             `"FUJIFILM"`,
		MakerNote:                        `"FUJIFILM0130" !"#,012NORMAL d"`,
		MaxApertureValue:                 `"300/100"`,
		MeteringMode:                     `5`,
		Model:                            `"FinePix E550   "`,
		Orientation:                      `1`,
		PixelXDimension:                  `2848`,
		PixelYDimension:                  `2136`,
		ResolutionUnit:                   `2`,
		SceneCaptureType:                 `0`,
		SceneType:                        `""`,
		SensingMethod:                    `2`,
		Sharpness:                        `0`,
		ShutterSpeedValue:                `"820/100"`,
		Software:                         `"Digital Camera FinePix E550    Ver1.00"`,
		SubjectDistanceRange:             `0`,
		ThumbJPEGInterchangeFormat:       `1306`,
		ThumbJPEGInterchangeFormatLength: `8596`,
		WhiteBalance:                     `1`,
		XResolution:                      `"72/1"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"72/1"`,
	},
	"2010-06-08-04-44-24-sep-2010-06-08-04-44-24a.jpg": map[FieldName]string{
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"8/1"`,
		Contrast:                         `0`,
		CustomRendered:                   `0`,
		DateTime:                         `"2010:06:08 04:44:24"`,
		DateTimeDigitized:                `"2010:06:08 04:44:24"`,
		DateTimeOriginal:                 `"2010:06:08 04:44:24"`,
		ExifIFDPointer:                   `2314`,
		ExifVersion:                      `"0221"`,
		ExposureBiasValue:                `"0/10"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `2`,
		ExposureTime:                     `"10/400"`,
		FNumber:                          `"28/10"`,
		FileSource:                       `""`,
		Flash:                            `31`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"51/10"`,
		ISOSpeedRatings:                  `80`,
		ImageDescription:                 `"                               "`,
		InteroperabilityIFDPointer:       `6640`,
		LightSource:                      `0`,
		Make:                             `"SONY"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"48/16"`,
		MeteringMode:                     `5`,
		Model:                            `"DSC-S600"`,
		Orientation:                      `1`,
		PixelXDimension:                  `2816`,
		PixelYDimension:                  `2112`,
		ResolutionUnit:                   `2`,
		Saturation:                       `0`,
		SceneCaptureType:                 `0`,
		SceneType:                        `""`,
		Sharpness:                        `0`,
		ThumbJPEGInterchangeFormat:       `6892`,
		ThumbJPEGInterchangeFormatLength: `4029`,
		WhiteBalance:                     `0`,
		XPKeywords:                       `[106,0,117,0,110,0,101,0,32,0,57,0,32,0,50,0,48,0,49,0,48,0,0,0]`,
		XResolution:                      `"72/1"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"72/1"`,
	},
	"2010-06-20-20-07-39-sep-2010-06-20-20-07-39a.jpg": map[FieldName]string{
		ApertureValue:                    `"116/32"`,
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"3/1"`,
		CustomRendered:                   `0`,
		DateTime:                         `"2010:10:31 22:39:25"`,
		DateTimeDigitized:                `"2010:06:20 20:07:39"`,
		DateTimeOriginal:                 `"2010:06:20 20:07:39"`,
		DigitalZoomRatio:                 `"3648/3648"`,
		ExifIFDPointer:                   `302`,
		ExifVersion:                      `"0220"`,
		ExposureBiasValue:                `"0/3"`,
		ExposureMode:                     `0`,
		ExposureTime:                     `"1/10"`,
		FNumber:                          `"35/10"`,
		FileSource:                       `""`,
		Flash:                            `16`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"9681/1000"`,
		FocalPlaneResolutionUnit:         `2`,
		FocalPlaneXResolution:            `"3648000/241"`,
		FocalPlaneYResolution:            `"2736000/181"`,
		ISOSpeedRatings:                  `800`,
		ImageDescription:                 `"                               "`,
		Make:                             `"Canon"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"116/32"`,
		MeteringMode:                     `5`,
		Model:                            `"Canon PowerShot SD1200 IS"`,
		Orientation:                      `1`,
		PixelXDimension:                  `3648`,
		PixelYDimension:                  `2736`,
		ResolutionUnit:                   `2`,
		SceneCaptureType:                 `0`,
		SensingMethod:                    `2`,
		ShutterSpeedValue:                `"106/32"`,
		Software:                         `"QuickTime 7.6.6"`,
		ThumbJPEGInterchangeFormat:       `3408`,
		ThumbJPEGInterchangeFormatLength: `5126`,
		UserComment:                      `""`,
		WhiteBalance:                     `0`,
		XResolution:                      `"4718592/65536"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"4718592/65536"`,
	},
	"2010-09-02-08-43-02-sep-2010-09-02-08-43-02a.jpg": map[FieldName]string{
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"1/1"`,
		Contrast:                         `0`,
		CustomRendered:                   `0`,
		DateTime:                         `"2010:09:02 08:43:02"`,
		DateTimeDigitized:                `"2010:09:02 08:43:02"`,
		DateTimeOriginal:                 `"2010:09:02 08:43:02"`,
		DigitalZoomRatio:                 `"0/100"`,
		ExifIFDPointer:                   `996`,
		ExifVersion:                      `"0221"`,
		ExposureBiasValue:                `"0/10"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `5`,
		ExposureTime:                     `"10/500"`,
		FNumber:                          `"53/10"`,
		FileSource:                       `""`,
		Flash:                            `65`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"210/10"`,
		GainControl:                      `2`,
		ISOSpeedRatings:                  `800`,
		ImageDescription:                 `"OLYMPUS DIGITAL CAMERA         "`,
		InteroperabilityIFDPointer:       `1714`,
		InteroperabilityIndex:            `"R98"`,
		LightSource:                      `0`,
		Make:                             `"OLYMPUS IMAGING CORP.  "`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"362/100"`,
		MeteringMode:                     `5`,
		Model:                            `"FE370,X880,C575        "`,
		Orientation:                      `1`,
		PixelXDimension:                  `3264`,
		PixelYDimension:                  `2448`,
		ResolutionUnit:                   `2`,
		Saturation:                       `0`,
		SceneCaptureType:                 `3`,
		SceneType:                        `""`,
		Sharpness:                        `0`,
		Software:                         `"Version 1.0                    "`,
		ThumbJPEGInterchangeFormat:       `9204`,
		ThumbJPEGInterchangeFormatLength: `3562`,
		UserComment:                      `"                                                                                                                             "`,
		WhiteBalance:                     `0`,
		XResolution:                      `"72/1"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"72/1"`,
	},
	"2011-01-24-22-06-02-sep-2011-01-24-22-06-02a.jpg": map[FieldName]string{
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CustomRendered:                   `0`,
		DateTimeDigitized:                `"2011:01:24 22:06:02"`,
		DateTimeOriginal:                 `"2011:01:24 22:06:02"`,
		DigitalZoomRatio:                 `"1024/1024"`,
		ExifIFDPointer:                   `157`,
		ExifVersion:                      `"0220"`,
		ExposureMode:                     `0`,
		FlashpixVersion:                  `"0100"`,
		Make:                             `"Nokia"`,
		MakerNote:                        `""`,
		Model:                            `"6350"`,
		Orientation:                      `1`,
		PixelXDimension:                  `1200`,
		PixelYDimension:                  `1600`,
		ResolutionUnit:                   `2`,
		SceneCaptureType:                 `0`,
		Software:                         `"V 12.40"`,
		ThumbJPEGInterchangeFormat:       `25601`,
		ThumbJPEGInterchangeFormatLength: `3385`,
		WhiteBalance:                     `0`,
		XResolution:                      `"300/1"`,
		YCbCrPositioning:                 `1`,
		YResolution:                      `"300/1"`,
	},
	"2011-03-07-09-28-03-sep-2011-03-07-09-28-03a.jpg": map[FieldName]string{
		BrightnessValue:                  `"0/1024"`,
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		Contrast:                         `0`,
		CustomRendered:                   `1`,
		DateTimeDigitized:                `"2011:03:07 09:28:03"`,
		DateTimeOriginal:                 `"2011:03:07 09:28:03"`,
		DigitalZoomRatio:                 `"0/0"`,
		ExifIFDPointer:                   `224`,
		ExifVersion:                      `"0220"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `2`,
		FileSource:                       `""`,
		FlashpixVersion:                  `"0100"`,
		InteroperabilityIFDPointer:       `538`,
		InteroperabilityIndex:            `"R98"`,
		Make:                             `"LG Elec."`,
		MeteringMode:                     `2`,
		Model:                            `"GU295"`,
		Orientation:                      `1`,
		PixelXDimension:                  `1280`,
		PixelYDimension:                  `960`,
		ResolutionUnit:                   `2`,
		Saturation:                       `0`,
		SceneType:                        `""`,
		Sharpness:                        `0`,
		Software:                         `"GU295-MSM1530032L-V10i-APR-22-2010-ATT-US"`,
		ThumbJPEGInterchangeFormat:       `662`,
		ThumbJPEGInterchangeFormatLength: `9850`,
		WhiteBalance:                     `0`,
		XResolution:                      `"72/1"`,
		YCbCrPositioning:                 `1`,
		YResolution:                      `"72/1"`,
	},
	"2011-05-07-13-02-49-sep-2011-05-07-13-02-49a.jpg": map[FieldName]string{
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		Contrast:                         `0`,
		DateTimeDigitized:                `"2011:05:07 13:02:49"`,
		DateTimeOriginal:                 `"2011:05:07 13:02:49"`,
		ExifIFDPointer:                   `218`,
		ExifVersion:                      `"0220"`,
		FileSource:                       `""`,
		FlashpixVersion:                  `"0100"`,
		GPSAltitude:                      `"0/1"`,
		GPSAltitudeRef:                   `0`,
		GPSDateStamp:                     `"2011:05:07 "`,
		GPSInfoIFDPointer:                `502`,
		GPSLatitude:                      `["0/1","0/1","0/100"]`,
		GPSLatitudeRef:                   `"N"`,
		GPSLongitude:                     `["0/1","0/1","0/100"]`,
		GPSLongitudeRef:                  `"E"`,
		GPSMapDatum:                      `"WGS-84"`,
		GPSProcessingMethod:              `"ASCIIHYBRID-FIX"`,
		GPSTimeStamp:                     `["19/1","3/1","43/1"]`,
		GPSVersionID:                     `[2,2,0,0]`,
		InteroperabilityIFDPointer:       `472`,
		InteroperabilityIndex:            `"R98"`,
		Make:                             `"HTC"`,
		Model:                            `"RAPH800"`,
		Orientation:                      `1`,
		PixelXDimension:                  `2048`,
		PixelYDimension:                  `1536`,
		ResolutionUnit:                   `2`,
		SceneType:                        `""`,
		Software:                         `"M7500BSAAAAAAD3050"`,
		ThumbJPEGInterchangeFormat:       `920`,
		ThumbJPEGInterchangeFormatLength: `22806`,
		WhiteBalance:                     `0`,
		XResolution:                      `"72/1"`,
		YCbCrPositioning:                 `1`,
		YResolution:                      `"72/1"`,
	},
	"2011-08-07-19-22-57-sep-2011-08-07-19-22-57a.jpg": map[FieldName]string{
		ApertureValue:                    `"433985/100000"`,
		CFAPattern:                       `""`,
		Contrast:                         `0`,
		CustomRendered:                   `0`,
		DateTime:                         `"2011:08:11 09:46:32"`,
		DateTimeDigitized:                `"2011:08:07 19:22:57"`,
		DateTimeOriginal:                 `"2011:08:07 19:22:57"`,
		DigitalZoomRatio:                 `"1/1"`,
		ExifIFDPointer:                   `186`,
		ExifVersion:                      `"0221"`,
		ExposureBiasValue:                `"2/6"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `3`,
		ExposureTime:                     `"1/30"`,
		FNumber:                          `"45/10"`,
		FileSource:                       `""`,
		Flash:                            `7`,
		FocalLength:                      `"620/10"`,
		FocalLengthIn35mmFilm:            `93`,
		GainControl:                      `1`,
		ISOSpeedRatings:                  `400`,
		LightSource:                      `0`,
		Make:                             `"NIKON CORPORATION"`,
		MaxApertureValue:                 `"43/10"`,
		MeteringMode:                     `2`,
		Model:                            `"NIKON D200"`,
		ResolutionUnit:                   `2`,
		Saturation:                       `0`,
		SceneCaptureType:                 `0`,
		SceneType:                        `""`,
		SensingMethod:                    `2`,
		Sharpness:                        `0`,
		ShutterSpeedValue:                `"4906891/1000000"`,
		Software:                         `"Ver.1.00"`,
		SubSecTimeDigitized:              `"65"`,
		SubSecTimeOriginal:               `"65"`,
		SubjectDistance:                  `"63/100"`,
		SubjectDistanceRange:             `0`,
		ThumbJPEGInterchangeFormat:       `802`,
		ThumbJPEGInterchangeFormatLength: `9117`,
		WhiteBalance:                     `0`,
		XResolution:                      `"300/1"`,
		YResolution:                      `"300/1"`,
	},
	"2011-10-28-17-50-18-sep-2011-10-28-17-50-18a.jpg": map[FieldName]string{
		ApertureValue:                    `"262144/65536"`,
		ColorSpace:                       `65535`,
		ComponentsConfiguration:          `""`,
		CustomRendered:                   `0`,
		DateTime:                         `"2011:11:08 07:27:55"`,
		DateTimeDigitized:                `"2011:10:28 17:50:18"`,
		DateTimeOriginal:                 `"2011:10:28 17:50:18"`,
		ExifIFDPointer:                   `364`,
		ExifVersion:                      `"0221"`,
		ExposureBiasValue:                `"0/1"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `2`,
		ExposureTime:                     `"1/60"`,
		FNumber:                          `"4/1"`,
		Flash:                            `9`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"34/1"`,
		FocalPlaneResolutionUnit:         `2`,
		FocalPlaneXResolution:            `"5616000/1459"`,
		FocalPlaneYResolution:            `"3744000/958"`,
		GPSInfoIFDPointer:                `1152`,
		GPSVersionID:                     `[2,2,0,0]`,
		ISOSpeedRatings:                  `800`,
		InteroperabilityIFDPointer:       `1120`,
		InteroperabilityIndex:            `"R03"`,
		Make:                             `"Canon"`,
		MeteringMode:                     `5`,
		Model:                            `"Canon EOS 5D Mark II"`,
		Orientation:                      `1`,
		PixelXDimension:                  `576`,
		PixelYDimension:                  `864`,
		ResolutionUnit:                   `2`,
		SceneCaptureType:                 `0`,
		ShutterSpeedValue:                `"393216/65536"`,
		Software:                         `"Adobe Photoshop CS4 Macintosh"`,
		SubSecTime:                       `"92"`,
		SubSecTimeDigitized:              `"92"`,
		SubSecTimeOriginal:               `"92"`,
		ThumbJPEGInterchangeFormat:       `1266`,
		ThumbJPEGInterchangeFormatLength: `6186`,
		UserComment:                      `""`,
		WhiteBalance:                     `1`,
		XResolution:                      `"720000/10000"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"720000/10000"`,
	},
	"2011-10-28-18-25-43-sep-2011-10-28-18-25-43.jpg": map[FieldName]string{
		CFAPattern:                       `""`,
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"2/1"`,
		Contrast:                         `0`,
		CustomRendered:                   `0`,
		DateTime:                         `"2011:10:28 18:25:43"`,
		DateTimeDigitized:                `"2011:10:28 18:25:43"`,
		DateTimeOriginal:                 `"2011:10:28 18:25:43"`,
		DigitalZoomRatio:                 `"1/1"`,
		ExifIFDPointer:                   `208`,
		ExifVersion:                      `"0221"`,
		ExposureBiasValue:                `"0/6"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `0`,
		ExposureTime:                     `"10/600"`,
		FNumber:                          `"56/10"`,
		FileSource:                       `""`,
		Flash:                            `31`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"800/10"`,
		FocalLengthIn35mmFilm:            `120`,
		GainControl:                      `2`,
		ISOSpeedRatings:                  `1250`,
		ImageUniqueID:                    `"7fa4f6d028df5f2fc1bad8102be81064"`,
		InteroperabilityIFDPointer:       `3604`,
		InteroperabilityIndex:            `"R98"`,
		LightSource:                      `0`,
		Make:                             `"NIKON CORPORATION"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"50/10"`,
		MeteringMode:                     `5`,
		Model:                            `"NIKON D80"`,
		Orientation:                      `1`,
		PixelXDimension:                  `800`,
		PixelYDimension:                  `537`,
		ResolutionUnit:                   `2`,
		Saturation:                       `0`,
		SceneCaptureType:                 `0`,
		SceneType:                        `""`,
		SensingMethod:                    `2`,
		Sharpness:                        `0`,
		Software:                         `"Ver.1.11 "`,
		SubSecTime:                       `"50"`,
		SubSecTimeDigitized:              `"50"`,
		SubSecTimeOriginal:               `"50"`,
		SubjectDistanceRange:             `0`,
		ThumbJPEGInterchangeFormat:       `3728`,
		ThumbJPEGInterchangeFormatLength: `3670`,
		UserComment:                      `"ASCII                                    "`,
		WhiteBalance:                     `0`,
		XResolution:                      `"300/1"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"300/1"`,
	},
	"2011-11-18-15-38-34-sep-Photo11181538.jpg": map[FieldName]string{
		BrightnessValue:                  `"0/1024"`,
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		Contrast:                         `1`,
		CustomRendered:                   `1`,
		DateTimeDigitized:                `"2011:11:18 15:38:34"`,
		DateTimeOriginal:                 `"2011:11:18 15:38:34"`,
		DigitalZoomRatio:                 `"0/0"`,
		ExifIFDPointer:                   `204`,
		ExifVersion:                      `"0220"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `2`,
		FileSource:                       `""`,
		FlashpixVersion:                  `"0100"`,
		InteroperabilityIFDPointer:       `518`,
		InteroperabilityIndex:            `"R98"`,
		Make:                             `"PANTECH"`,
		MeteringMode:                     `2`,
		Model:                            `"P2020"`,
		Orientation:                      `1`,
		PixelXDimension:                  `1600`,
		PixelYDimension:                  `1200`,
		ResolutionUnit:                   `2`,
		Saturation:                       `0`,
		SceneType:                        `""`,
		Sharpness:                        `0`,
		Software:                         `"M6290A-KPVMZL-2.6.0140T"`,
		ThumbJPEGInterchangeFormat:       `642`,
		ThumbJPEGInterchangeFormatLength: `12226`,
		WhiteBalance:                     `0`,
		XResolution:                      `"72/1"`,
		YCbCrPositioning:                 `1`,
		YResolution:                      `"72/1"`,
	},
	"2012-06-02-10-12-28-sep-2012-06-02-10-12-28.jpg": map[FieldName]string{
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"4/1"`,
		Contrast:                         `0`,
		CustomRendered:                   `0`,
		DateTime:                         `"2012:06:02 10:12:28"`,
		DateTimeDigitized:                `"2012:06:02 10:12:28"`,
		DateTimeOriginal:                 `"2012:06:02 10:12:28"`,
		DigitalZoomRatio:                 `"0/10"`,
		ExifIFDPointer:                   `636`,
		ExifVersion:                      `"0230"`,
		ExposureBiasValue:                `"0/100"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `2`,
		ExposureTime:                     `"10/4000"`,
		FNumber:                          `"33/10"`,
		FileSource:                       `""`,
		Flash:                            `16`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"50/10"`,
		FocalLengthIn35mmFilm:            `28`,
		GainControl:                      `0`,
		ISOSpeedRatings:                  `100`,
		InteroperabilityIFDPointer:       `10506`,
		InteroperabilityIndex:            `"R98"`,
		LightSource:                      `0`,
		Make:                             `"Panasonic"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"441/128"`,
		MeteringMode:                     `5`,
		Model:                            `"DMC-FH25"`,
		Orientation:                      `1`,
		PixelXDimension:                  `4608`,
		PixelYDimension:                  `3456`,
		ResolutionUnit:                   `2`,
		Saturation:                       `0`,
		SceneCaptureType:                 `0`,
		SceneType:                        `""`,
		SensingMethod:                    `2`,
		Sharpness:                        `0`,
		Software:                         `"Ver.1.0  "`,
		ThumbJPEGInterchangeFormat:       `11764`,
		ThumbJPEGInterchangeFormatLength: `7486`,
		WhiteBalance:                     `0`,
		XResolution:                      `"180/1"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"180/1"`,
	},
	"2012-09-21-22-07-34-sep-2012-09-21-22-07-34.jpg": map[FieldName]string{
		ApertureValue:                    `"95/32"`,
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"3/1"`,
		CustomRendered:                   `0`,
		DateTime:                         `"2012:09:21 22:07:34"`,
		DateTimeDigitized:                `"2012:09:21 22:07:34"`,
		DateTimeOriginal:                 `"2012:09:21 22:07:34"`,
		DigitalZoomRatio:                 `"4000/4000"`,
		ExifIFDPointer:                   `240`,
		ExifVersion:                      `"0221"`,
		ExposureBiasValue:                `"0/3"`,
		ExposureMode:                     `0`,
		ExposureTime:                     `"1/60"`,
		FNumber:                          `"28/10"`,
		FileSource:                       `""`,
		Flash:                            `25`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"5000/1000"`,
		FocalPlaneResolutionUnit:         `2`,
		FocalPlaneXResolution:            `"3264000/244"`,
		FocalPlaneYResolution:            `"2448000/183"`,
		ISOSpeedRatings:                  `500`,
		ImageDescription:                 `"                               "`,
		InteroperabilityIFDPointer:       `3288`,
		InteroperabilityIndex:            `"R98"`,
		Make:                             `"Canon"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"95/32"`,
		MeteringMode:                     `5`,
		Model:                            `"Canon PowerShot SD940 IS"`,
		Orientation:                      `1`,
		PixelXDimension:                  `3264`,
		PixelYDimension:                  `2448`,
		ResolutionUnit:                   `2`,
		SceneCaptureType:                 `2`,
		SensingMethod:                    `2`,
		ShutterSpeedValue:                `"189/32"`,
		ThumbJPEGInterchangeFormat:       `5108`,
		ThumbJPEGInterchangeFormatLength: `4855`,
		UserComment:                      `""`,
		WhiteBalance:                     `0`,
		XResolution:                      `"180/1"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"180/1"`,
	},
	"2012-12-19-21-38-40-sep-temple_square1.jpg": map[FieldName]string{
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		DateTimeDigitized:                `"2012:12:19 21:38:40"`,
		DateTimeOriginal:                 `"2012:12:19 21:38:40"`,
		ExifIFDPointer:                   `136`,
		ExifVersion:                      `"0220"`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"457/100"`,
		GPSAltitude:                      `"1334/1"`,
		GPSAltitudeRef:                   `0`,
		GPSDateStamp:                     `"2012:12:20"`,
		GPSInfoIFDPointer:                `352`,
		GPSLatitude:                      `["40/1","46/1","1322/100"]`,
		GPSLatitudeRef:                   `"N"`,
		GPSLongitude:                     `["111/1","53/1","2840/100"]`,
		GPSLongitudeRef:                  `"W"`,
		GPSMapDatum:                      `"WGS-84"`,
		GPSProcessingMethod:              `"ASCIIGPS"`,
		GPSTimeStamp:                     `["4/1","38/1","40/1"]`,
		GPSVersionID:                     `[2,2,0]`,
		ISOSpeedRatings:                  `801`,
		InteroperabilityIFDPointer:       `322`,
		InteroperabilityIndex:            `"R98"`,
		Make:                             `"HTC"`,
		Model:                            `"ADR6400L"`,
		PixelXDimension:                  `3264`,
		PixelYDimension:                  `1952`,
		ResolutionUnit:                   `2`,
		ThumbJPEGInterchangeFormat:       `696`,
		ThumbJPEGInterchangeFormatLength: `38469`,
		XResolution:                      `"72/1"`,
		YCbCrPositioning:                 `1`,
		YResolution:                      `"72/1"`,
	},
	"2012-12-21-11-15-19-sep-IMG_0001.jpg": map[FieldName]string{
		ApertureValue:                    `"286720/65536"`,
		Artist:                           `""`,
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		Copyright:                        `""`,
		CustomRendered:                   `0`,
		DateTime:                         `"2012:12:21 11:15:19"`,
		DateTimeDigitized:                `"2012:12:21 11:15:19"`,
		DateTimeOriginal:                 `"2012:12:21 11:15:19"`,
		ExifIFDPointer:                   `360`,
		ExifVersion:                      `"0230"`,
		ExposureBiasValue:                `"0/1"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `0`,
		ExposureTime:                     `"1/30"`,
		FNumber:                          `"45/10"`,
		Flash:                            `16`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"24/1"`,
		FocalPlaneResolutionUnit:         `2`,
		FocalPlaneXResolution:            `"5184000/894"`,
		FocalPlaneYResolution:            `"3456000/597"`,
		GPSInfoIFDPointer:                `9034`,
		GPSVersionID:                     `[2,3,0,0]`,
		ISOSpeedRatings:                  `1600`,
		InteroperabilityIFDPointer:       `8806`,
		InteroperabilityIndex:            `"R98"`,
		LensModel:                        `"EF-S18-55mm f/3.5-5.6 IS II"`,
		Make:                             `"Canon"`,
		MakerNote:                        `""`,
		MeteringMode:                     `5`,
		Model:                            `"Canon EOS REBEL T4i"`,
		Orientation:                      `1`,
		PixelXDimension:                  `5184`,
		PixelYDimension:                  `3456`,
		ResolutionUnit:                   `2`,
		SceneCaptureType:                 `0`,
		ShutterSpeedValue:                `"327680/65536"`,
		SubSecTime:                       `"00"`,
		SubSecTimeDigitized:              `"00"`,
		SubSecTimeOriginal:               `"00"`,
		ThumbJPEGInterchangeFormat:       `10924`,
		ThumbJPEGInterchangeFormatLength: `14327`,
		UserComment:                      `""`,
		WhiteBalance:                     `0`,
		XResolution:                      `"72/1"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"72/1"`,
	},
	"2013-02-05-23-12-09-sep-DSCI0001.jpg": map[FieldName]string{
		ApertureValue:                    `"3072/1000"`,
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"3766184/1920000"`,
		Copyright:                        `"Copyright 2005"`,
		DateTime:                         `"2013:02:05 23:12:09"`,
		DateTimeDigitized:                `"2013:02:05 23:12:09"`,
		DateTimeOriginal:                 `"2013:02:05 23:12:09"`,
		DigitalZoomRatio:                 `"100/100"`,
		ExifIFDPointer:                   `240`,
		ExifVersion:                      `"0210"`,
		ExposureBiasValue:                `"0/10"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `2`,
		ExposureTime:                     `"1/60"`,
		FNumber:                          `"28/10"`,
		FileSource:                       `""`,
		Flash:                            `1`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"5954/1000"`,
		FocalLengthIn35mmFilm:            `35`,
		ISOSpeedRatings:                  `100`,
		ImageDescription:                 `""`,
		InteroperabilityIFDPointer:       `4838`,
		InteroperabilityIndex:            `"R98"`,
		LightSource:                      `0`,
		Make:                             `"Polaroid"`,
		MakerNote:                        `" BARCODE:A265KS008000; ZP:812; FP:124; AWB:235,679; PWB:476,304; PMF:12,11610; LV:493; LUM:3-8-9-8-1-11;20;26;19;10;A:1,F1:6,F2:18;ET:145, W:2, F:3 ;FV:        41FV:        36FV:        43FV:       223FV:       258FV:         9FV:       466FV:       216FP: 10FP:  8FP:  6FP:  6FP:  6FP:  0FP:  8FP:  8AFS: 110"`,
		MaxApertureValue:                 `"3072/1000"`,
		MeteringMode:                     `3`,
		Model:                            `"Polaroid i532"`,
		Orientation:                      `1`,
		PixelXDimension:                  `1600`,
		PixelYDimension:                  `1200`,
		ResolutionUnit:                   `2`,
		SceneCaptureType:                 `0`,
		SceneType:                        `""`,
		SensingMethod:                    `2`,
		Sharpness:                        `0`,
		ShutterSpeedValue:                `"5907/1000"`,
		Software:                         `"  1.0"`,
		ThumbJPEGInterchangeFormat:       `4974`,
		ThumbJPEGInterchangeFormatLength: `5863`,
		WhiteBalance:                     `0`,
		XResolution:                      `"288/3"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"288/3"`,
	},
	"2099-08-12-19-59-29-sep-2099-08-12-19-59-29a.jpg": map[FieldName]string{
		CFAPattern:                       `""`,
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		CompressedBitsPerPixel:           `"2/1"`,
		Contrast:                         `1`,
		CustomRendered:                   `0`,
		DateTime:                         `"2099:08:12 19:59:29"`,
		DateTimeDigitized:                `"2099:08:12 19:59:29"`,
		DateTimeOriginal:                 `"2099:08:12 19:59:29"`,
		DigitalZoomRatio:                 `"1/1"`,
		ExifIFDPointer:                   `216`,
		ExifVersion:                      `"0221"`,
		ExposureBiasValue:                `"0/6"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `0`,
		ExposureTime:                     `"10/600"`,
		FNumber:                          `"35/10"`,
		FileSource:                       `""`,
		Flash:                            `31`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"180/10"`,
		FocalLengthIn35mmFilm:            `27`,
		GainControl:                      `0`,
		InteroperabilityIFDPointer:       `28448`,
		InteroperabilityIndex:            `"R98"`,
		LightSource:                      `0`,
		Make:                             `"NIKON CORPORATION"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"36/10"`,
		MeteringMode:                     `5`,
		Model:                            `"NIKON D70s"`,
		Orientation:                      `1`,
		PixelXDimension:                  `3008`,
		PixelYDimension:                  `2000`,
		ResolutionUnit:                   `2`,
		Saturation:                       `0`,
		SceneCaptureType:                 `0`,
		SceneType:                        `""`,
		SensingMethod:                    `2`,
		Sharpness:                        `0`,
		Software:                         `"Ver.1.00 "`,
		SubSecTime:                       `"00"`,
		SubSecTimeDigitized:              `"00"`,
		SubSecTimeOriginal:               `"00"`,
		SubjectDistanceRange:             `0`,
		ThumbJPEGInterchangeFormat:       `28588`,
		ThumbJPEGInterchangeFormatLength: `8886`,
		UserComment:                      `"ASCII                                    "`,
		WhiteBalance:                     `0`,
		XResolution:                      `"300/1"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"300/1"`,
	},
	"2216-11-15-11-46-51-sep-2216-11-15-11-46-51a.jpg": map[FieldName]string{
		ApertureValue:                    `"452/100"`,
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		Contrast:                         `0`,
		CustomRendered:                   `0`,
		DateTimeDigitized:                `"2216:11:15 11:46:51"`,
		DateTimeOriginal:                 `"2216:11:15 11:46:51"`,
		DigitalZoomRatio:                 `"0/10"`,
		ExifIFDPointer:                   `2316`,
		ExifVersion:                      `"0221"`,
		ExposureBiasValue:                `"0/10"`,
		ExposureIndex:                    `"80/1"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `2`,
		ExposureTime:                     `"1016/1000000"`,
		FNumber:                          `"480/100"`,
		FileSource:                       `""`,
		Flash:                            `24`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"60/10"`,
		FocalLengthIn35mmFilm:            `36`,
		GainControl:                      `0`,
		ISOSpeedRatings:                  `80`,
		InteroperabilityIFDPointer:       `17674`,
		LightSource:                      `0`,
		Make:                             `"EASTMAN KODAK COMPANY"`,
		MakerNote:                        `""`,
		MaxApertureValue:                 `"286/100"`,
		MeteringMode:                     `5`,
		Model:                            `"KODAK EASYSHARE C813 ZOOM DIGITAL CAMERA"`,
		Orientation:                      `1`,
		PixelXDimension:                  `3296`,
		PixelYDimension:                  `2472`,
		ResolutionUnit:                   `2`,
		Saturation:                       `0`,
		SceneCaptureType:                 `0`,
		SceneType:                        `""`,
		SensingMethod:                    `2`,
		Sharpness:                        `0`,
		ShutterSpeedValue:                `"994/100"`,
		Software:                         `"KODAK EASYSHARE C813 ZOOM DIGITAL CAMERA"`,
		SubjectDistanceRange:             `0`,
		ThumbJPEGInterchangeFormat:       `17818`,
		ThumbJPEGInterchangeFormatLength: `5175`,
		WhiteBalance:                     `0`,
		XResolution:                      `"480/1"`,
		YCbCrPositioning:                 `2`,
		YResolution:                      `"480/1"`,
	},
	"FailedHash-NoDate-sep-remembory.jpg": map[FieldName]string{
		ExifIFDPointer:  `192`,
		Make:            `"Brother"`,
		Model:           `"MFC-7840W"`,
		Orientation:     `1`,
		PixelXDimension: `1232`,
		PixelYDimension: `1626`,
		ResolutionUnit:  `2`,
		Software:        `"Apple Image Capture"`,
		XResolution:     `"150/1"`,
		YResolution:     `"150/1"`,
	},
	"f1-exif.jpg": map[FieldName]string{
		ColorSpace:              `65535`,
		ComponentsConfiguration: `""`,
		DateTime:                `"2012:11:04 05:42:02"`,
		ExifIFDPointer:          `134`,
		ExifVersion:             `"0210"`,
		FlashpixVersion:         `"0100"`,
		Orientation:             `1`,
		PixelXDimension:         `0`,
		PixelYDimension:         `0`,
		ResolutionUnit:          `2`,
		XResolution:             `"72/1"`,
		YCbCrPositioning:        `1`,
		YResolution:             `"72/1"`,
	},
	"f2-exif.jpg": map[FieldName]string{
		ColorSpace:              `65535`,
		ComponentsConfiguration: `""`,
		DateTime:                `"2012:11:04 05:42:32"`,
		ExifIFDPointer:          `134`,
		ExifVersion:             `"0210"`,
		FlashpixVersion:         `"0100"`,
		Orientation:             `2`,
		PixelXDimension:         `0`,
		PixelYDimension:         `0`,
		ResolutionUnit:          `2`,
		XResolution:             `"72/1"`,
		YCbCrPositioning:        `1`,
		YResolution:             `"72/1"`,
	},
	"f3-exif.jpg": map[FieldName]string{
		ColorSpace:              `65535`,
		ComponentsConfiguration: `""`,
		DateTime:                `"2012:11:04 05:42:32"`,
		ExifIFDPointer:          `134`,
		ExifVersion:             `"0210"`,
		FlashpixVersion:         `"0100"`,
		Orientation:             `3`,
		PixelXDimension:         `0`,
		PixelYDimension:         `0`,
		ResolutionUnit:          `2`,
		XResolution:             `"72/1"`,
		YCbCrPositioning:        `1`,
		YResolution:             `"72/1"`,
	},
	"f4-exif.jpg": map[FieldName]string{
		ColorSpace:              `65535`,
		ComponentsConfiguration: `""`,
		DateTime:                `"2012:11:04 05:42:32"`,
		ExifIFDPointer:          `134`,
		ExifVersion:             `"0210"`,
		FlashpixVersion:         `"0100"`,
		Orientation:             `4`,
		PixelXDimension:         `0`,
		PixelYDimension:         `0`,
		ResolutionUnit:          `2`,
		XResolution:             `"72/1"`,
		YCbCrPositioning:        `1`,
		YResolution:             `"72/1"`,
	},
	"f5-exif.jpg": map[FieldName]string{
		ColorSpace:              `65535`,
		ComponentsConfiguration: `""`,
		DateTime:                `"2012:11:04 05:42:32"`,
		ExifIFDPointer:          `134`,
		ExifVersion:             `"0210"`,
		FlashpixVersion:         `"0100"`,
		Orientation:             `5`,
		PixelXDimension:         `0`,
		PixelYDimension:         `0`,
		ResolutionUnit:          `2`,
		XResolution:             `"72/1"`,
		YCbCrPositioning:        `1`,
		YResolution:             `"72/1"`,
	},
	"f6-exif.jpg": map[FieldName]string{
		ColorSpace:              `65535`,
		ComponentsConfiguration: `""`,
		DateTime:                `"2012:11:04 05:42:32"`,
		ExifIFDPointer:          `134`,
		ExifVersion:             `"0210"`,
		FlashpixVersion:         `"0100"`,
		Orientation:             `6`,
		PixelXDimension:         `0`,
		PixelYDimension:         `0`,
		ResolutionUnit:          `2`,
		XResolution:             `"72/1"`,
		YCbCrPositioning:        `1`,
		YResolution:             `"72/1"`,
	},
	"f7-exif.jpg": map[FieldName]string{
		ColorSpace:              `65535`,
		ComponentsConfiguration: `""`,
		DateTime:                `"2012:11:04 05:42:32"`,
		ExifIFDPointer:          `134`,
		ExifVersion:             `"0210"`,
		FlashpixVersion:         `"0100"`,
		Orientation:             `7`,
		PixelXDimension:         `0`,
		PixelYDimension:         `0`,
		ResolutionUnit:          `2`,
		XResolution:             `"72/1"`,
		YCbCrPositioning:        `1`,
		YResolution:             `"72/1"`,
	},
	"f8-exif.jpg": map[FieldName]string{
		ColorSpace:              `65535`,
		ComponentsConfiguration: `""`,
		DateTime:                `"2012:11:04 05:42:32"`,
		ExifIFDPointer:          `134`,
		ExifVersion:             `"0210"`,
		FlashpixVersion:         `"0100"`,
		Orientation:             `8`,
		PixelXDimension:         `0`,
		PixelYDimension:         `0`,
		ResolutionUnit:          `2`,
		XResolution:             `"72/1"`,
		YCbCrPositioning:        `1`,
		YResolution:             `"72/1"`,
	},
	"geodegrees_as_string.jpg": map[FieldName]string{
		ApertureValue:                    `"2048/1024"`,
		Contrast:                         `0`,
		DateTimeOriginal:                 `"2014:04:26 19:09:19"`,
		ExifIFDPointer:                   `114`,
		ExposureProgram:                  `0`,
		ExposureTime:                     `"0/1024"`,
		FocalLength:                      `"3072/1024"`,
		GPSAltitude:                      `"0/1024"`,
		GPSAltitudeRef:                   `0`,
		GPSInfoIFDPointer:                `317`,
		GPSLatitude:                      `"52,00000,50,00000,34,01180"`,
		GPSLatitudeRef:                   `"N"`,
		GPSLongitude:                     `"11,00000,10,00000,58,28360"`,
		GPSLongitudeRef:                  `"E"`,
		GPSProcessingMethod:              `"ASCII"`,
		GPSTimeStamp:                     `"17,00000,8,00000,29,00000"`,
		ISOSpeedRatings:                  `125`,
		Make:                             `"HTC"`,
		Model:                            `"HTC One_M8"`,
		Saturation:                       `0`,
		Sharpness:                        `2`,
		ThumbJPEGInterchangeFormat:       `539`,
		ThumbJPEGInterchangeFormatLength: `13132`,
		WhiteBalance:                     `0`,
	},
	"has-lens-info.jpg": map[FieldName]string{
		ApertureValue:                    `"4845/1918"`,
		BrightnessValue:                  `"3927/419"`,
		ColorSpace:                       `1`,
		ComponentsConfiguration:          `""`,
		DateTime:                         `"2014:09:01 15:03:47"`,
		DateTimeDigitized:                `"2014:09:01 15:03:47"`,
		DateTimeOriginal:                 `"2014:09:01 15:03:47"`,
		ExifIFDPointer:                   `204`,
		ExifVersion:                      `"0221"`,
		ExposureMode:                     `0`,
		ExposureProgram:                  `2`,
		ExposureTime:                     `"1/1284"`,
		FNumber:                          `"12/5"`,
		Flash:                            `16`,
		FlashpixVersion:                  `"0100"`,
		FocalLength:                      `"107/25"`,
		FocalLengthIn35mmFilm:            `35`,
		GPSAltitude:                      `"29/1"`,
		GPSAltitudeRef:                   `0`,
		GPSImgDirection:                  `"18329/175"`,
		GPSImgDirectionRef:               `"T"`,
		GPSInfoIFDPointer:                `948`,
		GPSLatitude:                      `["59/1","19/1","5717/100"]`,
		GPSLatitudeRef:                   `"N"`,
		GPSLongitude:                     `["18/1","3/1","5379/100"]`,
		GPSLongitudeRef:                  `"E"`,
		GPSTimeStamp:                     `["13/1","3/1","4279/100"]`,
		ISOSpeedRatings:                  `50`,
		LensMake:                         `"Apple"`,
		LensModel:                        `"iPhone 4S back camera 4.28mm f/2.4"`,
		Make:                             `"Apple"`,
		MakerNote:                        `""`,
		MeteringMode:                     `5`,
		Model:                            `"iPhone 4S"`,
		Orientation:                      `6`,
		PixelXDimension:                  `3264`,
		PixelYDimension:                  `2448`,
		ResolutionUnit:                   `2`,
		SceneCaptureType:                 `0`,
		SceneType:                        `""`,
		SensingMethod:                    `2`,
		ShutterSpeedValue:                `"106906/10353"`,
		Software:                         `"7.1.1"`,
		SubSecTimeDigitized:              `"880"`,
		SubSecTimeOriginal:               `"880"`,
		SubjectArea:                      `[1631,1223,881,881]`,
		ThumbJPEGInterchangeFormat:       `1244`,
		ThumbJPEGInterchangeFormatLength: `10875`,
		WhiteBalance:                     `0`,
		XResolution:                      `"72/1"`,
		YCbCrPositioning:                 `1`,
		YResolution:                      `"72/1"`,
	},
}
